@@ -101,6 +101,62 @@ class Team:
         return [Integration(self, integration) for integration in response.json().get('data', {})]
 
 
+class AlertPolicy:
+    """Models the Alert Policy."""
+
+    def __init__(self, server, data):
+        self._logger = logging.getLogger(f'{LOGGER_BASENAME}.{self.__class__.__name__}')
+        self._server = server
+        self._data = data
+
+    @property
+    def id(self):  # pylint: disable=invalid-name, missing-docstring
+        return self._data.get('id')
+    
+    @property
+    def continue_after(self):  # pylint: disable=invalid-name, missing-docstring
+        return self._data.get('continue')
+
+    @property
+    def name(self):  # pylint: disable=missing-docstring
+        return self._data.get('name')
+
+    @property
+    def type(self):  # pylint: disable=missing-docstring
+        return self._data.get('type')
+
+    @property
+    def order(self):  # pylint: disable=missing-docstring
+        return self._data.get('order')
+    
+    @property
+    def enabled(self):  # pylint: disable=missing-docstring
+        return self._data.get('enabled')
+    
+    @property
+    def policy_description(self):  # pylint: disable=missing-docstring
+        return self._data.get('policyDescription')
+
+    @property
+    def tags(self):  # pylint: disable=missing-docstring
+        return self._data.get('tags')
+    
+    @property
+    def responders(self):  # pylint: disable=missing-docstring
+        return self._data.get('responders')
+
+    @property
+    def filter(self):  # pylint: disable=missing-docstring
+        return self._data.get('policyDescription')
+    
+    @property
+    def actions(self):  # pylint: disable=missing-docstring
+        return self._data.get('actions')
+    
+    @property
+    def details(self):  # pylint: disable=missing-docstring
+        return self._data.get('details')
+
 class Integration:
     """Models the integration."""
 
@@ -426,7 +482,7 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
         self._logger.debug('Making a call to "%s", with parameters "%s"', url, parameters)
         response = self._session.get(url, params=parameters)
         response.raise_for_status()
-        return response.json()
+        return AlertPolicy(self, response.json().get('data', {}))
 
     def list_alert_policy(self, team_id):
         """Listing all alert policies. Specify the team id."""
@@ -434,7 +490,7 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
         self._logger.debug('Making a call to "%s"', url)
         response = self._session.get(url)
         response.raise_for_status()
-        return response.json()
+        return [AlertPolicy(self, policy) for policy in response.json().get('data', {})]
 
     def list_integrations_by_team_name(self, team_name):
         """Listing integration based on teamnames. Returns the json."""
